
/* Generated data (by glib-mkenums) */

#include <glib-object.h>
#include "gtksourceview-typebuiltins.h"


/* enumerations from "gtksourceiter.h" */
static const GFlagsValue _gtk_source_search_flags_values[] = {
  { GTK_SOURCE_SEARCH_VISIBLE_ONLY, "GTK_SOURCE_SEARCH_VISIBLE_ONLY", "visible-only" },
  { GTK_SOURCE_SEARCH_TEXT_ONLY, "GTK_SOURCE_SEARCH_TEXT_ONLY", "text-only" },
  { GTK_SOURCE_SEARCH_CASE_INSENSITIVE, "GTK_SOURCE_SEARCH_CASE_INSENSITIVE", "case-insensitive" },
  { 0, NULL, NULL }
};

GType
gtk_source_search_flags_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("GtkSourceSearchFlags", _gtk_source_search_flags_values);

  return type;
}


/* enumerations from "gtksourceview.h" */
static const GEnumValue _gtk_source_view_smart_home_end_type_values[] = {
  { GTKSOURCEVIEW_SMART_HOME_END_DISABLED, "GTKSOURCEVIEW_SMART_HOME_END_DISABLED", "disabled" },
  { GTKSOURCEVIEW_SMART_HOME_END_BEFORE, "GTKSOURCEVIEW_SMART_HOME_END_BEFORE", "before" },
  { GTKSOURCEVIEW_SMART_HOME_END_AFTER, "GTKSOURCEVIEW_SMART_HOME_END_AFTER", "after" },
  { GTKSOURCEVIEW_SMART_HOME_END_ALWAYS, "GTKSOURCEVIEW_SMART_HOME_END_ALWAYS", "always" },
  { 0, NULL, NULL }
};

GType
gtk_source_view_smart_home_end_type_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GtkSourceViewSmartHomeEndType", _gtk_source_view_smart_home_end_type_values);

  return type;
}


/* Generated data ends here */

